.. image:: obv3_logo.jpg

Onionbalance
============

Introduction
------------

Onionbalance allows Tor onion service requests to be distributed across
multiple backend Tor instances. Onionbalance provides load-balancing while also
making onion services more resilient and reliable by eliminating single
points-of-failure.

Getting Started
---------------

Installation and usage documentation is available at https://onionbalance.readthedocs.org.

Contact
-------

This software is under active development and likely contains bugs. Please
open bug reports on Github if you discover any issues with the software or
documentation.

::

    pub   rsa4096 2012-02-22 [SC]
          13C81580203AE18BB7C0424E09CC7F5315F271D9
    uid           [ultimate] George Kadianakis <asn@torproject.org>
    uid           [ultimate] George Kadianakis <desnacked@riseup.net>
    sub   rsa4096 2012-02-22 [E]

The Onionbalance software was originally authored and maintained by Donncha Ó
Cearbhaill. Thanks for all the code!!!
